@@ -4,17 +4,14 @@
 import os
 import sys
 import tempfile
-try:
-    from runpy import run_module
-except ImportError:
-    pass #python2.4
 
+from cStringIO import StringIO
 from sqlalchemy import MetaData, Table
 from nose.plugins.skip import SkipTest
 
+from migrate.exceptions import *
 from migrate.versioning.repository import Repository
 from migrate.versioning import genmodel, shell, api
-from migrate.versioning.exceptions import *
 from migrate.tests.fixture import Shell, DB, usedb
 from migrate.tests.fixture import models
 
@@ -52,36 +49,45 @@ class TestShellCommands(Shell):
     def test_main_with_runpy(self):
         if sys.version_info[:2] == (2, 4):
             raise SkipTest("runpy is not part of python2.4")
+        from runpy import run_module
         try:
+            original = sys.argv
+            sys.argv=['X','--help']
+            
             run_module('migrate.versioning.shell', run_name='__main__')
-        except:
-            pass
 
+        finally:
+            sys.argv = original
+
+    def _check_error(self,args,code,expected,**kw):
+        original = sys.stderr
+        try:
+            actual = StringIO()
+            sys.stderr = actual
+            try:
+                shell.main(args,**kw)
+            except SystemExit, e:
+                self.assertEqual(code,e.args[0])
+            else:
+                self.fail('No exception raised')
+        finally:
+            sys.stderr = original
+        actual = actual.getvalue()
+        self.assertTrue(expected in actual,'%r not in:\n"""\n%s\n"""'%(expected,actual))
+            
     def test_main(self):
         """Test main() function"""
-        # TODO: test output?
         repos = self.tmp_repos()
         shell.main(['help'])
         shell.main(['help', 'create'])
         shell.main(['create', 'repo_name', '--preview_sql'], repository=repos)
         shell.main(['version', '--', '--repository=%s' % repos])
         shell.main(['version', '-d', '--repository=%s' % repos, '--version=2'])
-        try:
-            shell.main(['foobar'])
-        except SystemExit, e:
-            pass
-        try:
-            shell.main(['create', 'f', 'o', 'o'])
-        except SystemExit, e:
-            pass
-        try:
-            shell.main(['create'])
-        except SystemExit, e:
-            pass
-        try:
-            shell.main(['create', 'repo_name'], repository=repos)
-        except SystemExit, e:
-            pass
+
+        self._check_error(['foobar'],2,'error: Invalid command foobar')
+        self._check_error(['create', 'f', 'o', 'o'],2,'error: Too many arguments for command create: o')
+        self._check_error(['create'],2,'error: Not enough arguments for command create: name, repository not specified')
+        self._check_error(['create', 'repo_name'],2,'already exists', repository=repos)
 
     def test_create(self):
         """Repositories are created successfully"""
@@ -121,14 +127,14 @@ class TestShellCommands(Shell):
         repos = self.tmp_repos()
         result = self.env.run('migrate create %s repository_name' % repos)
 
-        result = self.env.run('migrate script_sql mydb %s' % repos)
-        self.assert_(os.path.exists('%s/versions/001_mydb_upgrade.sql' % repos))
-        self.assert_(os.path.exists('%s/versions/001_mydb_downgrade.sql' % repos))
+        result = self.env.run('migrate script_sql mydb foo %s' % repos)
+        self.assert_(os.path.exists('%s/versions/001_foo_mydb_upgrade.sql' % repos))
+        self.assert_(os.path.exists('%s/versions/001_foo_mydb_downgrade.sql' % repos))
 
         # Test creating a second
-        result = self.env.run('migrate script_sql postgres --repository=%s' % repos)
-        self.assert_(os.path.exists('%s/versions/002_postgres_upgrade.sql' % repos))
-        self.assert_(os.path.exists('%s/versions/002_postgres_downgrade.sql' % repos))
+        result = self.env.run('migrate script_sql postgres foo --repository=%s' % repos)
+        self.assert_(os.path.exists('%s/versions/002_foo_postgres_upgrade.sql' % repos))
+        self.assert_(os.path.exists('%s/versions/002_foo_postgres_downgrade.sql' % repos))
 
         # TODO: test --previews
 
@@ -473,14 +479,14 @@ class TestShellDatabase(Shell, DB):
         # Model is defined but database is empty.
         result = self.env.run('migrate compare_model_to_db %s %s --model=%s' \
             % (self.url, repos_path, model_module))
-        self.assert_("tables missing in database: tmp_account_rundiffs" in result.stdout)
+        self.assert_("tables missing from database: tmp_account_rundiffs" in result.stdout)
 
         # Test Deprecation
         result = self.env.run('migrate compare_model_to_db %s %s --model=%s' \
             % (self.url, repos_path, model_module.replace(":", ".")), expect_error=True)
         self.assertEqual(result.returncode, 0)
         self.assertTrue("DeprecationWarning" in result.stderr)
-        self.assert_("tables missing in database: tmp_account_rundiffs" in result.stdout)
+        self.assert_("tables missing from database: tmp_account_rundiffs" in result.stdout)
 
         # Update db to latest model.
         result = self.env.run('migrate update_db_from_model %s %s %s'\
